/*
 * Clutter-GStreamer.
 *
 * GStreamer integration library for Clutter.
 *
 * clutter.h - Top level header file.
 *
 * Copyright (C) 2006 OpenedHand
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __CLUTTER_GST_H__
#define __CLUTTER_GST_H__

#include <clutter/clutter.h>

#define __CLUTTER_GST_H_INSIDE__

#include "clutter-gst-types.h"
#include "clutter-gst-enum-types.h"
#include "clutter-gst-aspectratio.h"
#include "clutter-gst-camera-device.h"
#include "clutter-gst-camera-manager.h"
#include "clutter-gst-camera.h"
#include "clutter-gst-content.h"
#include "clutter-gst-crop.h"
#include "clutter-gst-playback.h"
#include "clutter-gst-player.h"
#include "clutter-gst-util.h"
#include "clutter-gst-version.h"

#endif /* __CLUTTER_GST_H__ */
